@@ -70,6 +70,11 @@ class Backend(s3c.Backend):
     def __str__(self):
         return 'Amazon S3 bucket %s, prefix %s' % (self.bucket_name, self.prefix)
 
+    @property
+    @copy_ancestor_docstring
+    def has_delete_multi(self):
+        return True
+
     @copy_ancestor_docstring
     def delete_multi(self, keys, force=False):
         log.debug('started with %s', keys)
@@ -181,11 +186,12 @@ class Backend(s3c.Backend):
         auth_strs.append(urllib.parse.quote(path))
 
         if query_string:
-            s = urllib.parse.urlencode(query_string, doseq=True).split('&')
+            s = urllib.parse.urlencode(query_string, doseq=True,
+                                       quote_via=urllib.parse.quote).split('&')
         else:
             s = []
         if subres:
-            s.append(urllib.parse.quote_plus(subres) + '=')
+            s.append(urllib.parse.quote(subres) + '=')
         if s:
             s = '&'.join(sorted(s))
         else:
